--------------------------------------------------------------------------------
-- An example of a simple circuit for running a tutorial on VHDL and EDA tools
-- equations (structural)

-- Step 6 in VHDL EDA design flow ---> Programming the prototyping board
--------------------------------------------------------------------------------
-- NOTE: The port naming are adapted to the active levels MAX II MICRO KIT BOARD 
-- LED outputs and push-buttons are active low. 

-- The adaptation is a multiple file design as in P3 (components + signals)
--------------------------------------------------------------------------------
-- Exercise P3  - CSD - Multiple-file VHDL design
-- http://digsys.upc.edu
--------------------------------------------------------------------------------
LIBRARY ieee;
USE  IEEE.STD_LOGIC_1164.all;

ENTITY Circuit_W_top IS
	PORT (
		D_L		: IN STD_LOGIC_VECTOR(1 DOWNTO 0); --> KEY3, KEY2
		A_L,B_L	: IN STD_LOGIC;      -->  KEY1, KEY0
		
		W_L		: OUT STD_LOGIC; --> Connected to LED2
		
--The active-low not used LED will be set --> OFF
		LED0, LED1, LED3, LED4, LED5, LED6, LED7	: OUT STD_LOGIC
	);
END Circuit_W_top; 

ARCHITECTURE MAXII_microkit_adaptation OF Circuit_W_top IS
	
-- The elemental components to be used:
	COMPONENT Circuit_W IS  
		PORT (
			D		: IN STD_LOGIC_VECTOR(1 DOWNTO 0); 
			A,B		: IN STD_LOGIC;      
			W		: OUT STD_LOGIC
		);
	END COMPONENT;

-- Signals
signal D		: STD_LOGIC_VECTOR(1 DOWNTO 0);
signal A,B		: STD_LOGIC;      
signal W		: STD_LOGIC;


BEGIN

-- Instantiation of the Circuit_W:

	Chip1	: Circuit_W
		PORT MAP (
-- from component name 	=> to signal or port name
				D	=> D,
				A	=> A,
				B	=> B,
				W	=> W			
		);

-- Other circuits and equations to dapt active-low inputs and outputs
	W_L <= not W;
	
	--D <= not(D_L);
	
	D(1) <= not (D_L(1));
	D(0) <= not (D_L(0));
	A <= not (A_L);
	B <= not (B_L);	


	--The active-low not used LED will be set --> OFF
	LED0 <= '1';
	LED1 <= '1';
	LED3 <= '1';
	LED4 <= '1';
	LED5 <= '1';
	LED6 <= '1';
	LED7 <= '1';	
	
			 		   	 		 		   	   
END MAXII_microkit_adaptation;
